@@ -3,12 +3,17 @@
  * Automatic command-line wildcard expansion for environments that
  * are not based on the Un*x shell.
  *
- * Copyright (C) 2003-2014 Cosmin Truta.
+ * Copyright (C) 2003-2017 Cosmin Truta.
  *
  * This software is distributed under the zlib license.
  * Please see the accompanying LICENSE file.
  */
 
+/*
+ * Dummy header inclusion for a guaranteed non-empty translation unit.
+ */
+#include <stddef.h>
+
 /*
  * Automatic wildcard expansion for Microsoft Visual C++.
  */
